@@ -10,10 +10,9 @@ def _get_history():
              .history(period='1w', interval='1h')
 
 def _prepare_df(data):
-    print(data.index.name)
     data.index = data.index.tz_convert(time.tzname[0])
     data.index = data.index.tz_localize(None)
-    print(data)
+
     return data.reset_index() \
                .rename(columns={'index': 'ds', 'Close': 'y'}) \
                .loc[:, ['ds', 'y']]
@@ -26,12 +25,12 @@ def train_model(filepath='models/btc_model.pkl'):
     with open(filepath, 'wb') as file:
         pickle.dump(model, file)
 
-def read_model(filepath='btc_model.pkl'):
+def read_model(filepath='models/btc_model.pkl'):
     return pickle.load(open(filepath, 'rb'))
 
 def get_preidction(n_steps, plot_filepath='static/plot.png'):
     model = read_model()
-    forecast = model.predict(model.make_future_dataframe(periods=n_steps))
+    forecast = model.predict(model.make_future_dataframe(periods=n_steps, freq=3600))
     model.plot(forecast.iloc[-144:]).savefig(plot_filepath)
 
     return forecast.iloc[-n_steps:][['ds', 'yhat', 'yhat_lower', 'yhat_upper']]
